# Installation

### Version: 1.1.0

###### Requirements:

- PHP: 8.3
- MariaDB: 10.5.22
- Ioncube loaders.

Update the server:
`sudo dnf update -y && sudo dnf upgrade -y`

Install Apache:
`dnf install httpd nano zip unzip wget php-pdo_mysql php-pdo npm -y`

Start and Enable Apache on Boot:
`sudo systemctl enable httpd && sudo systemctl start httpd`

Let's allow Apache threw the firewall:

```
sudo firewall-cmd --zone=public --add-service=http --permanent
 sudo firewall-cmd --zone=public --add-service=https --permanent
 sudo firewall-cmd --reload
```

Now it’s time to install PHP:

```
dnf install https://rpms.remirepo.net/enterprise/remi-release-9.rpm -y
dnf module switch-to php:remi-8.3/common -y
sudo dnf install php php-cli php-fpm php-curl php-mysqlnd php-gd php-opcache php-zip php-intl php-common php-bcmath php-json php-readline php-mbstring php-apcu php-xml php-dom -y
```

Now let’s get MariaDB Installed:
`yum install mariadb-server -y`

Enable and start MariaDB:
`sudo systemctl enable mariadb && sudo systemctl start mariadb`

To set-up MariaDB run:
`mysql_secure_installation`

Let’s log into MySQL:
`mysql -u root -p`

Create database and user:
`CREATE DATABASE ticaga;`
`CREATE USER 'ticaga_user'@'localhost' IDENTIFIED BY 'p@s3w0r$2024!';`
`GRANT ALL PRIVILEGES ON ticaga.* TO 'ticaga_user'@'localhost';`
`FLUSH PRIVILEGES;`
`exit;`

### Create a virtual host file:

Create the folders:
`mkdir /etc/httpd/sites-available /etc/httpd/sites-enabled`

`echo "IncludeOptional sites-enabled/*.conf" >> /etc/httpd/conf/httpd.conf`

Time to make your virtual host:
`nano /etc/httpd/sites-available/support.yourdomain.com.conf`

Paste in the following:

```
<VirtualHost *:80>
     ServerName support.yourdomain.com
     DocumentRoot /var/www/ticaga/public
     <Directory /var/www/ticaga/public>
          Options FollowSymlinks
          AllowOverride All
          Require all granted
          <Files .env>
					  Order allow,deny
					  Deny from all
					</Files>
     </Directory>

     ErrorLog /var/log/httpd/support.yourdomain.com_error.log
     CustomLog /var/log/httpd/support.yourdomain.com.log combined
</VirtualHost>
```

Copy the file to the sites enabled.
`sudo ln -s /etc/httpd/sites-available/support.yourdomain.com.conf /etc/httpd/sites-enabled/support.yourdomain.com.conf`

#### Installing Composer:

```
php -r "copy('https://getcomposer.org/installer', 'composer-setup.php');"
php -r "if (hash_file('sha384', 'composer-setup.php') === 'dac665fdc30fdd8ec78b38b9800061b4150413ff2e3b6f88543c636f7cd84f6db9189d43a81e5503cda447da73c7e5b6') { echo 'Installer verified'; } else { echo 'Installer corrupt'; unlink('composer-setup.php'); } echo PHP_EOL;"
php composer-setup.php
php -r "unlink('composer-setup.php');"

sudo mv composer.phar /usr/local/bin/composer
```

#### Lets Encrypt (SSL):

```
dnf install certbot python3-certbot-apache mod_ssl -y
wget https://getcomposer.org/installer -O composer-installer.php
php composer-installer.php --filename=composer --install-dir=/usr/local/bin
certbot --apache
```

#### Install Ioncube Loaders:

```
sudo wget -N https://downloads.ioncube.com/loader_downloads/ioncube_loaders_lin_x86-64.zip
sudo unzip ioncube_loaders_lin_x86-64.zip
sudo mv ./ioncube/ioncube_loader_lin_8.3.so /usr/lib64/php/modules/ioncube_loader_lin_8.3.so
sudo nano /etc/php.ini
```

Paste this near the top:
`zend_extension = /usr/lib64/php/modules/ioncube_loader_lin_8.3.so`

```
sudo rm -rf ./ioncube
sudo rm -rf ./ioncube_loaders_lin_x86-64.zip
```

Create a new user for SSH so you’re not using root:
`sudo useradd -m -d /home/ticaga name`
`sudo passwd name`
`sudo usermod -aG wheel name`

Now log in as **name**.
`su name`

`sudo chown -R name:apache /var/www/`

`cd /var/www/`

`composer create-project --prefer-dist laravel/laravel ticaga`

Go into the **ticaga** folder:
`cd ticaga`

Then remove all the files:
`rm -rf ./*`
*Please be safe and ensure the **./** is before else you can delete everything. Any doubts about this please contact
your system admin or our technical team*

Get the Ticaga files:
`wget -N https://ticaga.com/latest.zip`

Unzip the files:
`unzip latest.zip`
`sudo rm -rf ./__MACOSX`

Provide the files the correct permissions:
`sudo chown -R apache: ./*`

Time to give the correct permissions to the storage folder:
`sudo chmod -R 775 storage/`

Time to sort Mod Security:
`sudo sed -c -i "s/\SELINUX=.*/SELINUX=disabled/" /etc/selinux/config`

```
semanage fcontext -a -t httpd_sys_rw_content_t "/var/www/ticaga/storage(/.*)?"
semanage fcontext -a -t httpd_sys_rw_content_t "/var/www/ticaga/bootstrap/cache(/.*)?"
restorecon -Rv /var/www/ticaga
sudo setsebool -P httpd_can_network_connect_db 1
```

Now you can edit the **.env** for Ticaga.
`sudo mv .env.example .env`

`APP_NAME=Your_Company`
`APP_URL=https://yourdomain.com`
`DEFAULT_DEPARTMENT=slug_for_the_department`

`DB_CONNECTION=mysql`
`DB_HOST=127.0.0.1`
`DB_PORT=3306`
`DB_DATABASE=database_name`
`DB_USERNAME=database_username`
`DB_PASSWORD=datebase_user_password`

After you’ve edited the .env with the above customisations, you can now create your Application Key (Secret hash):
`sudo php artisan key:generate`

Let’s sort the storage out so you and your customers can upload user pictures:
`sudo php artisan storage:link`

Let’s create the database tables:
`sudo php artisan migrate`

Install Vite
`sudo rm -rf node_modules/`
`sudo npm install`
`sudo npm install -g vite`
`sudo chown -R $USER /var/www/ticaga`

Build the application:
`sudo npm run build`

Reboot the server to kick Ioncube into action:
`sudo reboot`
` cd /var/www/ticaga`
` su name`

Now load Ticaga up:
`sudo php artisan serve`



