<?php

    namespace App\Http\Controllers;

    use App\Models\Departments;
    use App\Models\Tickets;
    use Illuminate\Support\Carbon;
    use Illuminate\Support\Str;

    class DepartmentsController extends Controller
    {
        /**
         * Change the department of a ticket.
         */
        public static function change($department_info)
        {
            Tickets::where('id', $department_info['ticket_id'])
                ->update([
                    'department_id' => $department_info['department_id'],
                ]);
        }

        /**
         * Update the specified resource in storage.
         */
        public static function update($department)
        {
            Departments::where('id', $department['department_id'])
                ->update([
                    'department_name' => $department['department_name'],
                    'slug' => Str::lower($department['department_slug']),
                    'department_description' => $department['department_description'],
                    'department_email' => $department['department_email'],
                    'show_opening_hours' => '0',
                    'allows_high_priority' => $department['allows_high_priority'],
                    'is_public' => $department['display_department'],
                    'is_disabled' => $department['is_disabled'],
                ]);
        }

        /**
         * Store a newly created resource in storage.
         */
        public static function store($department)
        {
            return Departments::insert([
                'department_name' => $department['department_name'],
                'slug' => Str::lower($department['slug']),
                'department_description' => $department['department_description'],
                'department_email' => $department['department_email'],
                'department_open' => null,
                'department_closed' => null,
                'show_opening_hours' => '0',
                'allows_high_priority' => $department['allows_high_priority'],
                'is_disabled' => $department['is_disabled'],
                'created_at' => Carbon::now(),
                'updated_at' => null,
            ]);
        }

        /**
         * Display a listing of the resource.
         */
        public function index()
        {
            return view('tickets.departments');
        }

        /**
         * Show the form for creating a new resource.
         */
        public function create()
        {
            //
        }

        /**
         * Display the specified resource.
         */
        public function show(Departments $departments)
        {
            //
        }

        /**
         * Show the form for editing the specified resource.
         */
        public function edit(int $department_id)
        {
            return view('departments.edit', [
                'department_id' => $department_id
            ]);
        }

        /**
         * Remove the specified resource from storage.
         */
        public function destroy(Departments $departments)
        {
            //
        }
    }
