<?php

    namespace App\Http\Controllers;

    use App\Mail\NewTicket;
    use App\Models\Departments;
    use App\Models\Tickets;
    use App\Models\User;
    use Illuminate\Http\Request;
    use Illuminate\Support\Carbon;
    use Illuminate\Support\Facades\Auth;
    use Illuminate\Support\Facades\DB;
    use Illuminate\Support\Facades\Mail;

    class TicketsController extends Controller
    {
        /**
         * Display the ticket
         */
        public static function show(string $ticketId)
        {
            $check_ticket = Tickets::where('tickets.id', '=', $ticketId)
                ->where('tickets.user_id', '=', Auth::user()->id)
                ->first();

            if ($check_ticket != null or Auth::user()->is_agent != '0') {
                $ticket = Tickets::where('tickets.id', '=', $ticketId)
                    ->leftJoin('users', 'tickets.user_id', '=', 'users.id')
                    ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                    ->select('tickets.*', 'departments.id', 'departments.department_name', 'users.company',
                        'users.name', 'users.email')
                    ->selectRaw('users.company as company_name, users.name as client_name, tickets.id as ticket_id, departments.id as department_unique_id')
                    ->first();

                return view('tickets.view_ticket', [
                    'ticket' => $ticket,
                ]);
            } else {
                // Not the customer's ticket and not an Agent. Need to do Error Handling here.
                return view('tickets.index');
            }
        }

        /**
         * Displays all tickets assigned to user.
         */
        public static function mine()
        {
            if (Auth::user()->is_agent == '1') {
                return view('tickets.show_mine');
            } else {
                return view('tickets.index');
            }
        }

        /**
         * Stores the ticket into the database.
         */
        public static function store($ticket)
        {
            $create_ticket = Tickets::create([
                'user_id' => Auth::user()->id ?? '0',
                'subject' => $ticket['subject'],
                'content' => $ticket['content'],
                'status' => 'open',
                'priority' => $ticket['priority'],
                'cc' => $ticket['cc'] ?? '',
                'assigned' => Auth::user()->account_manager ?? '0',
                'department_id' => $ticket['department_id'],
                'public_hash' => $ticket['public_hash'],
                'public_name' => $ticket['public_name'] ?? null,
                'public_email' => $ticket['public_email'] ?? null,
                'rating' => '0',
                'ip_address' => app('request')->ip(),
                'date_closed' => null,
                'updated_by_client_at' => Carbon::now(),
                'created_at' => Carbon::now(),
                'updated_at' => null,
            ]);

            $user_email = Auth::check() ? Auth::user()->email : $grab_ticket[0]['public_email'];

            // Grabs all the ticket details into an array for the email.
            $grab_ticket = Tickets::where('id', '=', $create_ticket->id)->get()->toArray();

            // Send email to customer & Agents
            $agents = User::select('email')->where('is_agent', '=', '1')->pluck('email')->toArray();
            if (isset($ticket['cc']) && $ticket['cc'] != '') {
                Mail::to($user_email)->cc($ticket['cc'])->bcc($agents)->send(new NewTicket($grab_ticket[0],
                    $ticket['public_hash']));
            } else {
                Mail::to($user_email)->bcc($agents)->send(new NewTicket($grab_ticket[0]));
            }

            return $create_ticket->id;
        }

        /**
         * Shows the form for creating a new ticket.
         */
        public function create(Request $request, string $departmentSlug)
        {
            if (Auth::check()) {
                if (Auth::user()->is_agent == '1') {
                    $department = Departments::where('slug', '=', $departmentSlug)
                        ->first();
                } else {
                    $department = Departments::where('slug', '=', $departmentSlug)
                        ->where('is_disabled', '!=', '1')
                        ->first();
                }
                if ($department) {
                    return view('tickets.open_ticket', [
                        'department_id' => $department->id,
                        'department' => $department,
                    ]);
                } else {
                    return view('tickets.index');
                }
            } else {
                $department = Departments::where('slug', '=', $departmentSlug)
                    ->where('is_public', '=', '1')
                    ->first();
                if ($department) {
                    return view('tickets.open_ticket', [
                        'department_id' => $department->id,
                        'department' => $department,
                    ]);
                } else {
                    $departments = Departments::where('is_public', '=', '1')->get();

                    return view('tickets.departments', [
                        'departments' => $departments,
                    ]);
                }
            }
        }

        public static function grab($ticket_id)
        {
            return DB::table('tickets')->select('id', 'public_hash')->where('id', '=', $ticket_id)->first();
        }

        public static function change_rating($rating)
        {
            return Tickets::where('id', $rating['ticket_id'])
                ->update([
                    'rating' => $rating['rating'],
                ]);
        }

        /**
         * Update the specified resource in storage.
         */
        public function update(Request $request, Tickets $tickets)
        {
            //
        }

        /**
         * Change the customer of a ticket.
         */
        public static function change_customer($ticket)
        {
            Tickets::where('id', $ticket['ticket_id'])
                ->update([
                    'user_id' => $ticket['customer_id'],
                ]);
        }

        /**
         * Shows the ticket to the public, with the valid ticket id and hash.
         */
        public function public(Request $request, string $ticketId, string $ticketHash)
        {

            $public_check = Tickets::where('id', '=', $ticketId)
                ->where('public_hash', '=', $ticketHash)
                ->first();
            if ($public_check) {
                $ticket = Tickets::where('tickets.id', '=', $ticketId)
                    ->leftJoin('users', 'tickets.user_id', '=', 'users.id')
                    ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                    ->where('tickets.public_hash', '=', $ticketHash)
                    ->select('tickets.*', 'departments.*', 'users.*')
                    ->selectRaw('users.company as company_name, users.name as client_name, tickets.id as ticket_id, departments.id as department_unique_id')
                    ->first();

                return view('tickets.view_ticket', [
                    'ticket' => $ticket,
                ]);
            } else {
                return view('welcome');
            }
        }

        /**
         * Display the tickets in a list.
         */
        public function index()
        {
            return view('tickets.index');
        }

        /**
         * Display the form for creating a department.
         */
        public function create_department()
        {
            return view('departments.create');
        }

        /**
         * Show the form for editing the specified resource.
         */
        public function edit(Tickets $tickets)
        {
            //
        }

        /*
         * Grabs the ticket id and public_hash
         */

        /**
         * Remove the specified resource from storage.
         */
        public function destroy(Tickets $tickets)
        {
            //
        }


    }
