<?php

    namespace App\Livewire\Clients;

    use App\Models\Tickets as Ticket;
    use Carbon\Carbon;
    use Illuminate\Support\Facades\Auth;
    use Livewire\Attributes\Url;
    use Livewire\Component;
    use Livewire\WithPagination;

    class ClosedTickets extends Component
    {
        use WithPagination;

        public Ticket $ticket;

        public $user;
        #[Url]
        public $sortColumn;
        #[Url]
        public $sortAsc = false;

        public function mount($user)
        {
            $this->user = $user;
        }

        public function render()
        {
            $tickets = Ticket::where('users.id', '=', $this->user->id)
                ->where('status', '=', 'closed')
                ->leftJoin('users', 'tickets.user_id', '=', 'users.id')
                ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                ->select('tickets.*', 'departments.*')
                ->selectRaw('users.name as client_name, tickets.id as ticket_id, departments.id as department_unique_id');

            $tickets = $this->applySorting($tickets);

            if ($tickets) {
                return view('livewire.clients.closed-tickets', [
                    'tickets' => $tickets->paginate('10'),
                ]);
            } else {
                return view('livewire.clients.closed-tickets', [
                    'tickets' => null,
                ]);
            }
        }

        protected function applySorting($query)
        {
            if ($this->sortColumn) {
                $column = match ($this->sortColumn) {
                    'ticket_id' => 'tickets.id',
                    'status' => 'tickets.status',
                    'priority' => 'tickets.priority',
                };
                $query->orderBy($column, $this->sortAsc ? 'asc' : 'desc');
            }
            return $query;
        }

        public function sortBy($column)
        {
            if ($this->sortColumn === $column) {
                $this->sortAsc = !$this->sortAsc;
            } else {
                $this->sortColumn = $column;
                $this->sortAsc = false;
            }
        }

        public function close($ticket_id)
        {
            if (Auth::user()->is_agent == '1') {
                Ticket::where('tickets.id', '=', $ticket_id)
                    ->update([
                        'status' => 'closed',
                        'date_closed' => Carbon::now(),
                    ]);
            }
        }
    }
