<?php

    namespace App\Livewire\Tickets;

    use App\Http\Controllers\ResponsesController;
    use App\Models\Tickets;
    use Illuminate\Support\Carbon;
    use Illuminate\Support\Facades\Auth;
    use Livewire\Attributes\Rule;
    use Livewire\Component;

    class CommentBox extends Component
    {
        #[Rule('required', message: "We can't help you if you don't tell us what's wrong :(.")]
        public $response_content = '';
        public $response_title = '';
        public $response_type = [];

        public $ticket_id;

        public function mount($ticket_id)
        {
            $this->ticket_id = $ticket_id;
        }

        public function send()
        {
            if ($this->response_type == '1') {
                $is_note = '1';
            } else {
                $is_note = '0';
                $check_priority = Tickets::where('id', '=', $this->ticket_id)->first();
                if ($check_priority->status != 'in progress') {
                    Tickets::where('id', '=', $this->ticket_id)->update(['status' => 'awaiting reply']);
                }
            }

            if (Auth::check()) {
                if (Auth::user()->is_agent == '1') {
                    $is_agent = '1';
                } else {
                    $is_agent = '0';
                    $check_priority = Tickets::where('id', '=', $this->ticket_id)
                        ->first();
                    if ($check_priority->status != 'in progress') {
                        Tickets::where('id', '=', $this->ticket_id)->update(['status' => 'open']);
                    }
                }
            }

            $this->validate();

            ResponsesController::store([
                'response_title' => $this->response_title,
                'response_content' => $this->response_content,
                'ticket_number' => $this->ticket_id,
                'is_note' => $is_note,
                'agent_response' => $is_agent,
            ]);
            if (Auth::check()) {
                $this->redirect('/tickets/show/'.$this->ticket_id);
            } else {
                $this->redirect('/tickets/public/'.$this->ticket_id.'/'.$check_priority->public_hash);
            }


            $this->reset();
        }

        public function render()
        {
            return view('livewire.tickets.comment-box');
        }

        public function close($ticket_id)
        {

            if (Auth::check() and Auth::user()->is_agent == '1') {
                $user = Tickets::where('tickets.id', '=', $ticket_id)->first();
            } else {
                if (Auth::check()) {
                    $client_id = Auth::user()->id;
                    $user = Tickets::where('tickets.id', '=', $ticket_id)
                        ->where('user_id', '=', $client_id)
                        ->first();
                } else {
                    $user = Tickets::where('tickets.id', '=', $ticket_id)
                        ->first();
                }
            }
            if ($user) {
                Tickets::where('id', '=', $ticket_id)->update([
                    'status' => 'closed', 'date_closed' => Carbon::now(), 'updated_at' => Carbon::now()
                ]);
                if (Auth::check()) {
                    $this->redirect('/tickets/show/'.$this->ticket_id);
                } else {
                    $this->redirect('/tickets/public/'.$this->ticket_id.'/'.$user->public_hash);
                }

                $this->reset();
            }
        }
    }
