<?php

    namespace App\Livewire\Tickets;

    use App\Http\Controllers\TicketsController;
    use App\Models\Departments;
    use Illuminate\Support\Facades\Auth;
    use Livewire\Attributes\Rule;
    use Livewire\Component;

    class CreateTicketForm extends Component
    {
        public $departmentId;

        #[Rule(message: "Please enter your full name, so we can personalize our reply.")]
        public $public_name = '';

        #[Rule(message: "Please enter your email address, so you get our reply.")]
        public $public_email = '';

        #[Rule('required', message: "Please enter a subject.")]
        public $subject;

        public $cc;

        #[Rule('required', message: "Please select a priority for your ticket.")]
        public $priority = '';

        #[Rule('required', message: "Please enter the reason you are contacting us?")]
        public $content;

        public function mount($departmentId)
        {
            $this->departmentId = $departmentId;
        }

        public function save()
        {
            $this->validate();

            $token = bin2hex(random_bytes(16));
            $public_hash = hash_hmac('sha256', $token, env('APP_KEY'));

            $ticket_id = TicketsController::store([
                'public_name' => $this->public_name,
                'public_email' => $this->public_email,
                'subject' => $this->subject,
                'cc' => $this->cc,
                'priority' => $this->priority,
                'content' => $this->content,
                'department_id' => $this->departmentId,
                'public_hash' => $public_hash,
            ]);

            if (Auth::check()) {
                $this->redirect('/tickets/show/'.$ticket_id);
            } else {
                $public_ticket = TicketsController::grab($ticket_id);
                $this->redirect('/tickets/public/'.$public_ticket->id.'/'.$public_ticket->public_hash);
            }

        }

        public function render()
        {
            $department_info = Departments::where('id', '=', $this->departmentId)->first();
            return view('livewire.tickets.create-ticket-form', [
                'department_info' => $department_info,
                'ip_address' => app('request')->ip(),
            ]);
        }
    }
