<?php

    namespace App\Livewire\Tickets;

    use App\Models\Tickets;
    use Carbon\Carbon;
    use Illuminate\Support\Facades\Auth;
    use Illuminate\Support\Facades\DB;
    use Livewire\Attributes\Url;
    use Livewire\Component;
    use Livewire\WithPagination;

    class Mine extends Component
    {

        use WithPagination;

        #[Url]
        public $sortColumn;
        #[Url]
        public $sortAsc = false;

        public $selectedRows = [];
        public $allRows = [];

        public function render()
        {

            $tickets = Tickets::where('assigned', '=', Auth::user()->id)
                ->leftJoin('users', 'tickets.user_id', '=', 'users.id')
                ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                ->select('tickets.*', 'departments.*')
                ->selectRaw('users.name as client_name, tickets.id as ticket_id, departments.id as department_unique_id');

            $tickets = $this->applySorting($tickets);

            $tickets = $tickets->paginate('10');

            $this->allRows = $tickets->map(fn($tickets) => (string) $tickets->ticket_id)->toArray();
            return view('livewire.tickets.mine', [
                'tickets' => $tickets,
            ]);
        }

        protected function applySorting($query)
        {
            if ($this->sortColumn) {
                $column = match ($this->sortColumn) {
                    'ticket_id' => 'tickets.id',
                    'status' => 'tickets.status',
                    'priority' => 'tickets.priority',
                };
                $query->orderBy($column, $this->sortAsc ? 'asc' : 'desc');
            }
            return $query;
        }

        public function sortBy($column)
        {
            if ($this->sortColumn === $column) {
                $this->sortAsc = !$this->sortAsc;
            } else {
                $this->sortColumn = $column;
                $this->sortAsc = false;
            }
        }

        public function closeSelected()
        {
            $tickets = DB::table('tickets')->select('tickets.id')->whereIn('id', $this->selectedRows)->get();
            foreach ($tickets as $ticket) {
                $this->close($ticket->id);
            }
            $this->reset();
        }

        public function close($ticket_id)
        {
            if (Auth::user()->is_agent == '1') {
                Tickets::where('tickets.id', '=', $ticket_id)
                    ->update([
                        'status' => '1',
                        'date_closed' => Carbon::now(),
                    ]);
            }
        }
    }
