<?php

    namespace App\Livewire\Tickets;

    use App\Mail\ClosedTicket;
    use App\Models\Tickets;
    use App\Models\User;
    use Illuminate\Support\Carbon;
    use Illuminate\Support\Facades\Auth;
    use Illuminate\Support\Facades\Mail;
    use Livewire\Attributes\Lazy;
    use Livewire\Attributes\Url;
    use Livewire\Component;
    use Livewire\WithPagination;

    #[Lazy]
    class View extends Component
    {
        use WithPagination;

        public $search = '';
        #[Url]
        public $sortColumn;
        #[Url]
        public $sortAsc = false;
        public $selectedRows = [];
        public $allRows = [];

        public function render()
        {
            if (Auth::user()->is_agent == '1') {
                $tickets = Tickets::leftJoin('users', 'tickets.user_id', '=', 'users.id')
                    ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                    ->select('tickets.*', 'departments.*', 'users.*')
                    ->selectRaw('users.company as company_name, users.name as client_name, tickets.id as ticket_id, departments.id as department_unique_id');
            } else {
                $tickets = Tickets::leftJoin('users', 'tickets.user_id', '=', 'users.id')
                    ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                    ->select('tickets.*', 'departments.*')
                    ->selectRaw('users.name as client_name, tickets.id as ticket_id, departments.id as department_unique_id')
                    ->where('user_id', '=', Auth::user()->id);
            }

            $tickets = $this->applySearch($tickets);
            $tickets = $this->applySorting($tickets);

            $tickets = $tickets->paginate('10');

            $this->allRows = $tickets->map(fn($tickets) => (string) $tickets->ticket_id)->toArray();
            return view('livewire.tickets.view', [
                'tickets' => $tickets,
            ]);
        }

        protected function applySearch($query)
        {
            return $this->search === ''
                ? $query
                : $query
                    ->where('users.name', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.id', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.subject', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.public_name', 'like', '%'.$this->search.'%')
                    ->orWhere('departments.department_name', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.status', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.priority', 'like', '%'.$this->search.'%');
        }

        protected function applySorting($query)
        {
            if ($this->sortColumn) {
                $column = match ($this->sortColumn) {
                    'ticket_id' => 'tickets.id',
                    'status' => 'tickets.status',
                    'priority' => 'tickets.priority',
                };
                $query->orderBy($column, $this->sortAsc ? 'asc' : 'desc');
            }
            return $query;
        }

        public function sortBy($column)
        {
            if ($this->sortColumn === $column) {
                $this->sortAsc = !$this->sortAsc;
            } else {
                $this->sortColumn = $column;
                $this->sortAsc = false;
            }
        }

        public function closeSelected()
        {
            $tickets = Tickets::whereIn('id', $this->selectedRows)->select('tickets.id')->get();
            foreach ($tickets as $ticket) {
                $this->close($ticket->id);
            }
            $this->reset();
        }

        public function close($ticket_id)
        {
            $client_id = Auth::user()->id;
            if (Auth::user()->is_agent == '1') {
                $user = Tickets::where('tickets.id', '=', $ticket_id)
                    ->first();
                $user_id = $user['user_id'];
                $email = User::select('email')->selectRaw('email')->where('id', '=', $user_id)->first();
            } else {
                $user = Tickets::where('tickets.id', '=', $ticket_id)
                    ->where('user_id', '=', $client_id)
                    ->first();

                $email = User::select('email')->selectRaw('email')->where('id', '=', $client_id)->first();
            }
            if ($user) {
                Tickets::where('id', '=', $ticket_id)
                    ->update(['status' => 'closed', 'date_closed' => Carbon::now(), 'updated_at' => Carbon::now()]);

                // Grabs all the ticket details into an array for the email.
                $grab_ticket = Tickets::where('id', '=', $ticket_id)->get()->toArray();

                // Grabs the email address for the customer.
                $user_email = $email ? $email->email : $grab_ticket[0]['public_email'];
                Mail::to($user_email)->send(new ClosedTicket($grab_ticket[0]));
            }
        }

        public function updatedSearch()
        {
            $this->resetPage();
        }
    }
