<?php

    namespace App\Livewire\Widgets\Agents;

    use App\Models\Tickets as Ticket;
    use Livewire\Attributes\Url;
    use Livewire\Component;
    use Livewire\WithPagination;

    class Tickets extends Component
    {
        use WithPagination;

        public $search = '';
        #[Url]
        public $sortColumn;
        #[Url]
        public $sortAsc = false;
        public $selectedRows = [];
        public $allRows = [];

        public Ticket $ticket;

        public function render()
        {
            $tickets = Ticket::where('tickets.status', '!=', 'closed')
                ->leftJoin('users', 'tickets.user_id', '=', 'users.id')
                ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                ->select('tickets.*', 'departments.department_name as department_name', 'users.company as company_name',
                    'users.name as client_name',
                    'tickets.id as ticket_id', 'departments.id as department_unique_id');

            $tickets = $this->applySearch($tickets);
            $tickets = $this->applySorting($tickets);

            $tickets = $tickets->paginate(5);

            $this->allRows = $tickets->map(fn($tickets) => (string) $tickets->ticket_id)->toArray();

            return view('livewire.widgets.agents.tickets', [
                'tickets' => $tickets,
            ]);
        }

        protected function applySearch($query)
        {
            return $this->search === ''
                ? $query
                : $query
                    ->where('users.name', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.id', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.subject', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.public_name', 'like', '%'.$this->search.'%')
                    ->orWhere('departments.department_name', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.status', 'like', '%'.$this->search.'%')
                    ->orWhere('tickets.priority', 'like', '%'.$this->search.'%');
        }

        protected function applySorting($query)
        {
            if ($this->sortColumn) {
                $column = match ($this->sortColumn) {
                    'ticket_id' => 'tickets.id',
                    'status' => 'tickets.status',
                    'priority' => 'tickets.priority',
                };
                $query->orderBy($column, $this->sortAsc ? 'asc' : 'desc');
            }
            return $query;
        }

        public function sortBy($column)
        {
            if ($this->sortColumn === $column) {
                $this->sortAsc = !$this->sortAsc;
            } else {
                $this->sortColumn = $column;
                $this->sortAsc = false;
            }
        }

        public function updatedSearch()
        {
            $this->resetPage();
        }
    }
