<?php

    namespace App\Livewire\Widgets;

    use App\Models\Tickets as Ticket;
    use Carbon\Carbon;
    use Illuminate\Support\Facades\Auth;
    use Livewire\Component;
    use Livewire\WithPagination;

    class Tickets extends Component
    {
        use WithPagination;

        public Ticket $ticket;

        public function render()
        {
            $tickets = Ticket::where('users.id', '=', Auth::user()->id)
                ->leftJoin('users', 'tickets.user_id', '=', 'users.id')
                ->leftJoin('departments', 'tickets.department_id', '=', 'departments.id')
                ->select('tickets.*', 'departments.*')
                ->selectRaw('users.name as client_name, tickets.id as ticket_id, departments.id as department_unique_id');

            return view('livewire.widgets.tickets', [
                'tickets' => $tickets->paginate('5'),
            ]);
        }

        public function close($ticket_id)
        {
            Ticket::where('id', $ticket_id)
                ->update([
                    'status' => '1',
                    'date_closed' => Carbon::now(),
                ]);
        }
    }
