<?php
    /**
     * Ticaga Library
     *
     * Application integration code, used for validating license data supplied by
     * the Ticaga Licensing System Plugin as-well as other features.
     *
     * @copyright Copyright (c) 2016-2022, Ticaga.
     */

    namespace App\Models;

    use Illuminate\Database\Eloquent\Factories\HasFactory;
    use Illuminate\Database\Eloquent\Model;

    class TicagaLibrary extends Model
    {
        use HasFactory;

        private $TicagaLibrary;

        /**
         * Initializes the LicensingCommunicationLibrary only after verifying its trustworhiness
         *
         * @param  string  $path_to_phpseclib  The full path to the phpseblib library
         * @param  string  $install_path  The full server path to the root directory of the client software. Defaults
         *     to current directory.
         * @see TicagaLibrary:getLibrary();
         */
        public function __construct($path_to_phpseclib, $signature_mode = null, $install_path = null)
        {

            if ($this->verify()) {
                $signature_mode = "sha256";
                require_once(dirname(__FILE__).DIRECTORY_SEPARATOR."Core.php");


                $this->Core = new Core($path_to_phpseclib,
                    $signature_mode, $install_path);

            }
        }

        /**
         * Verify that the license manager can be initialized.
         *
         * @return bool True if the license manager is valid
         * @throws Exception If the license manager is invalid and therefore cannot be initialized
         */
        private function verify()
        {
            // $hash = [
            // '3614e6de0e805b7d1b5684777512406c02a1bbb50a3016f0dc2aeb943ad8e7d0'
            // ];

            // if (!in_array(hash_file('sha256', dirname(__FILE__) . DS . 'manager.php'), $hash)) {
            // throw new \Exception('Invalid License Verification Class, Class can not be initialized.');
            // }

            return true;
        }

        /**
         * Returns the TicagaLibrary
         *
         * @return TicagaLibrary The initialized TicagaLibrary object
         */
        public function getLibrary()
        {
            return $this->Core;
        }
    }
