<?php

    namespace App\Models;

    use App\Enums\Priorities;
    use App\Enums\Status;
    use Illuminate\Database\Eloquent\Factories\HasFactory;
    use Illuminate\Database\Eloquent\Model;
    use Illuminate\Database\Eloquent\Relations\BelongsTo;
    use Illuminate\Database\Eloquent\Relations\HasMany;

    class Tickets extends Model
    {
        use HasFactory;

        /**
         * The attributes that are mass assignable.
         *
         * @var array<int, string>
         */
        protected $fillable = [
            'user_id', 'subject', 'content', 'status', 'priority', 'cc', 'assigned', 'public_hash', 'public_name',
            'public_email', 'ip_address',
        ];

        /**
         * The attributes that should be hidden for serialization.
         *
         * @var array<int, string>
         */
        protected $hidden = [];

        /**
         * The attributes that should be cast.
         *
         * @var array<string, string>
         */
        protected $casts = [
            'status' => Status::class,
            'priority' => Priorities::class,
        ];

        /**
         * The accessors to append to the model's array form.
         *
         * @var array<int, string>
         */
        protected $appends = [];

        public function user(): BelongsTo
        {
            return $this->belongsTo(User::class());
        }

        public function responses(): HasMany
        {
            return $this->hasMany(Responses::class);
        }

    }
