<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}" x-data="{darkMode: false}"
      :class="{'dark': darkMode === true }">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no"/>

    <title>@if(Auth::check() && Auth::user()->is_agent > '0' && $ticket_count)
            [ {{ $ticket_count }} ]
        @endif @yield('title', config('app.name', 'Ticaga'))</title>

    <script src="https://kit.fontawesome.com/0861a3f1fb.js" crossorigin="anonymous"></script>
    <link rel="preconnect" href="https://fonts.bunny.net">
    <link href="https://fonts.bunny.net/css?family=figtree:400,600&display=swap" rel="stylesheet"/>
    <!-- Scripts -->
    @vite(['resources/css/app.css', 'resources/js/app.js'])
    <!-- Styles -->
    @livewireStyles
</head>
<body x-cloak x-data="{darkMode: $persist(false)}" :class="{'dark': darkMode === true }"
      class="antialiased min-h-screen flex flex-col flex-auto flex-shrink-0 bg-gray-100 dark:bg-gray-800 text-black dark:text-white">
<x-mary-toast/>
<x-banner/>
<header
    class="fixed w-full px-3 flex items-center justify-between h-14 bg-gray-100 dark:bg-gray-700 text-black dark:text-white z-10">
    <div class="flex items-center justify-start pl-3 border-none ms-3">
        <x-logo/>
    </div>
    <div class="flex justify-between items-center h-14">
        <ul class="flex items-center right-0">
            <li>
                <x-theme-toggle/>
            </li>
            @auth
                <div class="sm:flex sm:items-center sm:ms-4 ">
                    <!-- Teams Dropdown -->
                    @if (Auth::user()->company != '')
                        <div class="ms-3 relative hidden md:block">
                            <x-dropdown align="right" width="60">
                                <x-slot name="trigger">
                                <span class="inline-flex rounded-md">
                                    <button type="button"
                                            class="inline-flex items-center px-3 py-2 border border-transparent text-sm leading-4 font-medium rounded-md text-gray-500 dark:text-gray-400 bg-white dark:bg-gray-800 hover:text-gray-700 dark:hover:text-gray-300 focus:outline-none focus:bg-gray-50 dark:focus:bg-gray-700 active:bg-gray-50 dark:active:bg-gray-700 transition ease-in-out duration-150">
                                        {{ Auth::user()->currentTeam->name }}

                                        <svg class="ms-2 -me-0.5 h-4 w-4" xmlns="http://www.w3.org/2000/svg" fill="none"
                                             viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor">
                                            <path stroke-linecap="round" stroke-linejoin="round"
                                                  d="M8.25 15L12 18.75 15.75 15m-7.5-6L12 5.25 15.75 9"/>
                                        </svg>
                                    </button>
                                </span>
                                </x-slot>

                                <x-slot name="content">
                                    <div class="w-60">
                                        <!-- Team Management -->
                                        <div class="block px-4 py-2 text-xs text-gray-400">
                                            {{ __('Manage Company') }}
                                        </div>

                                        <!-- Team Settings -->
                                        <x-dropdown-link
                                            href="{{ route('teams.show', Auth::user()->currentTeam->id) }}">
                                            {{ __('Company Settings') }}
                                        </x-dropdown-link>

                                        <!-- Team Switcher -->
                                        @if (Auth::user()->allTeams()->count() > 1)
                                            <div class="border-t border-gray-200 dark:border-gray-600"></div>

                                            <div class="block px-4 py-2 text-xs text-gray-400">
                                                {{ __('Switch Companies') }}
                                            </div>

                                            @foreach (Auth::user()->allTeams() as $team)
                                                <x-switchable-team :team="$team"/>
                                            @endforeach
                                        @endif
                                    </div>
                                </x-slot>
                            </x-dropdown>
                        </div>
                    @endif
                    <!-- Settings Dropdown -->
                    <div class="ms-3 relative">
                        <x-dropdown align="right" width="48">
                            <x-slot name="trigger">
                                @if (Laravel\Jetstream\Jetstream::managesProfilePhotos())
                                    <button
                                        class="flex text-sm border-2 border-transparent rounded-full focus:outline-none focus:border-gray-300 transition">
                                        <img class="h-8 w-8 rounded-full object-cover"
                                             src="{{ Auth::user()->profile_photo_url }}"
                                             alt="{{ Auth::user()->name }}"/>
                                    </button>
                                @else
                                    <span class="inline-flex rounded-md">
                                    <button type="button"
                                            class="inline-flex items-center px-3 py-2 border border-transparent text-sm leading-4 font-medium rounded-md text-gray-500 dark:text-gray-400 bg-white dark:bg-gray-800 hover:text-gray-700 dark:hover:text-gray-300 focus:outline-none focus:bg-gray-50 dark:focus:bg-gray-700 active:bg-gray-50 dark:active:bg-gray-700 transition ease-in-out duration-150">
                                        {{ Auth::user()->name }}

                                        <svg class="ms-2 -me-0.5 h-4 w-4" xmlns="http://www.w3.org/2000/svg" fill="none"
                                             viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor">
                                            <path stroke-linecap="round" stroke-linejoin="round"
                                                  d="M19.5 8.25l-7.5 7.5-7.5-7.5"/>
                                        </svg>
                                    </button>
                                </span>
                                @endif
                            </x-slot>
                            <x-slot name="content">
                                <!-- Account Management -->
                                <div class="block px-4 py-2 text-xs text-gray-400">
                                    {{ __('Manage Account') }}
                                </div>

                                <x-dropdown-link href="{{ route('profile.show') }}">
                                    {{ __('Profile') }}
                                </x-dropdown-link>
                                @if(Auth::user()->id == '1')
                                    <x-dropdown-link href="{{ route('licensing') }}">
                                        {{ __('Ticaga Management') }}
                                    </x-dropdown-link>
                                @endif
                                @if (Laravel\Jetstream\Jetstream::hasApiFeatures())
                                    <x-dropdown-link href="{{ route('api-tokens.index') }}">
                                        {{ __('API Tokens') }}
                                    </x-dropdown-link>
                                @endif

                                <div class="border-t border-gray-200 dark:border-gray-600"></div>

                                <!-- Authentication -->
                                <form method="POST" action="{{ route('logout') }}" x-data>
                                    @csrf

                                    <x-dropdown-link href="{{ route('logout') }}"
                                                     @click.prevent="$root.submit();">
                                        {{ __('Log Out') }}
                                    </x-dropdown-link>
                                </form>
                            </x-slot>
                        </x-dropdown>
                    </div>
                </div>
            @else
                <li>
                    <a href="{{ route('login') }}"
                       class="lg:inline-flex gap-2.5 items-center rounded-lg px-4 py-2 text-sm font-medium transition-colors focus:outline-none focus-visible:ring focus-visible:ring-pink-400/50 text-gray-600 hover:text-gray-800 hover:bg-gray-400/10 focus:outline focus:outline-2 focus:rounded-sm focus:outline-red-500">
                        <span class="fa-solid fa-user-lock font-semibold text-gray-800 dark:text-gray-400"></span>
                        <span
                            class="font-semibold text-gray-800 hover:text-gray-900 dark:text-gray-400 dark:hover:text-white">
                            Log in
                        </span>
                    </a>
                </li>
                @if (Route::has('register'))
                    <li>
                        <a href="{{ route('register') }}"
                           class="lg:inline-flex gap-2.5 items-center rounded-lg px-4 py-2 text-sm font-medium transition-colors focus:outline-none focus-visible:ring focus-visible:ring-pink-400/50 text-gray-600 hover:text-gray-800 hover:bg-gray-400/10 focus:outline focus:outline-2 focus:rounded-sm focus:outline-red-500">
                            <span
                                class="fa-solid fa-file-contract font-semibold text-gray-800 dark:text-gray-400"></span>
                            <span
                                class="font-semibold text-gray-800 hover:text-gray-900 dark:text-gray-400 dark:hover:text-white">
                                Register
                            </span>
                        </a>
                    </li>
                @endif
            @endauth
        </ul>
    </div>
</header>
<div class="bg-gray-100 dark:bg-gray-800">
    <!-- Sidebar -->
    <livewire:navigation-menu/>

    <!-- Page Content -->
    <section class="min-h-screen ml-14 md:ml-64 px-4 bg-gray-50 dark:bg-gray-800">
        <!-- Page Heading -->
        @if (isset($header))
            <header class="bg-opacity-25 text-gray-900 dark:bg-gray-800 mt-10">
                <div class=" mt-3 max-w-7xl mx-auto py-10 sm:px-6 lg:px-8">
                    {{ $header }}
                </div>
            </header>
        @endif
        <section class="mt-4">{{ $slot }}</section>
        <p class="py-3 text-center text-black dark:text-white text-xs">
            Copyright &copy; {{ now()->year }} {{ getenv('APP_NAME') }}. Powered by <a href="https://ticaga.com/"
                                                                                       target="_blank">Ticaga</a>
        </p>
        @stack('modals')
    </section>
</div>
@livewireScripts
</body>
</html>

