<div wire:model.live.debounce.500ms>
    <div class="relative">
        @if($tickets->total() > 0)
            <table class="min-w-full text-left text-sm font-light">
                <thead
                    class="border-b bg-white font-medium dark:border-gray-500 dark:bg-gray-700 dark:text-white">
                <tr>
                    <th scope="col" class="px-6 py-4">
                        <x-livewire.tickets.selectall/>
                    </th>
                    <th scope="col" class="px-6 py-4">
                        <x-livewire.tickets.sortable column="ticket_id" :$sortColumn :$sortAsc>
                            #
                        </x-livewire.tickets.sortable>
                    </th>
                    <th scope="col" class="px-6 py-4">Subject</th>
                    @if(Auth::user()->is_agent > '0')
                        <th scope="col" class="px-6 py-4">Account holder</th>
                    @endif
                    <th scope="col" class="px-6 py-4">
                        <x-livewire.tickets.sortable column="status" :$sortColumn :$sortAsc>
                            Status
                        </x-livewire.tickets.sortable>
                    </th>
                    <th scope="col" class="px-6 py-4">
                        <x-livewire.tickets.sortable column="priority" :$sortColumn :$sortAsc>
                            Priority
                        </x-livewire.tickets.sortable>
                    </th>
                    <th scope="col" class="px-6 py-4">Department</th>
                    <th scope="col" class="px-6 py-4">
                        @if(Auth::user()->is_agent == '1')
                            <input wire:model.live.debounce.500ms="search" type="text" placeholder="Search tickets"
                                   class="transition-color block w-full max-w-[16rem] rounded-[10px] border-0 bg-gray-300 dark:bg-gray-800 pr-4 text-sm text-gray-800 dark:text-gray-300 placeholder-gray-400 dark:placeholder-gray-600 outline-none sm:max-w-none">
                        @endif
                    </th>
                </tr>
                </thead>
                <tbody wire:poll.visible>
                @foreach($tickets as $ticket)
                    <tr wire:key="{{ $ticket->ticket_id }}"
                        @if(Auth::user()->is_agent == '1' and $ticket->assigned == Auth::user()->id)
                            class="border-b bg-blue-300 dark:border-gray-800"
                        @elseif(Auth::user()->is_agent == '1' and $ticket->assigned != Auth::user()->id and $ticket->assigned != '0')
                            class="border-b bg-gray-300 dark:border-gray-800"
                        @else
                            class="border-b bg-gray-100 dark:border-gray-800 dark:bg-gray-900 dark:text-white"
                        @endif>
                        <td class="whitespace-nowrap px-6 py-4">
                            <div class="flex items-center">
                                <input type="checkbox" wire:model.live="selectedRows" value="{{ $ticket->ticket_id }}"
                                       class="rounded border-gray-300 shadow">
                            </div>
                        </td>
                        <td class="whitespace-nowrap px-6 py-4 font-medium">
                            <a href="{{ env('APP_URL') }}/tickets/show/{{ $ticket->ticket_id }}">
                                {{ $ticket->ticket_id }}
                            </a>
                        </td>
                        <td class="whitespace-nowrap px-6 py-4">{{ str($ticket->subject)->words(6) }}</td>
                        @if(Auth::user()->is_agent > '0')
                            <td class="whitespace-nowrap px-6 py-4 capitalize">
                                @if($ticket->client_name != '')
                                    <a href="{{ env('APP_URL') }}/clients/show/{{ $ticket->user_id }}">{{ $ticket->client_name }}@if(isset($ticket->company_name))
                                            :: {{ $ticket->company_name  }}
                                        @endif
                                    </a>
                                @else
                                    {{ $ticket->public_name }}
                                @endif
                            </td>
                        @endif
                        <td class="whitespace-nowrap px-6 py-4 capitalize">
                            <div class="badge text-white text-xs px-2 py-2 border-transparent bg-slate-900"
                                 style="background: {{ $ticket->status->colour() }};">
                                {{ $ticket->status->label() ?? 'Unknown Status' }}
                            </div>
                        </td>
                        <td class="whitespace-nowrap px-6 py-4 capitalize">
                            <div class="badge text-white text-xs px-2 py-2 border-transparent bg-slate-900"
                                 style="background: {{ $ticket->priority->colour() }};">
                                {{ $ticket->priority->label() ?? 'No Priority' }}
                            </div>
                        </td>
                        <td class="whitespace-nowrap px-6 py-4">
                            {{ $ticket->department_name }}
                        </td>
                        <td class="whitespace-nowrap px-6 py-4">
                            <a class="btn btn-sm btn-neutral text-white"
                               href="{{ env('APP_URL') }}/tickets/show/{{ $ticket->ticket_id }}">View
                            </a>
                            <button class="btn btn-sm btn-error text-white"
                                    type="button"
                                    wire:click="close({{ $ticket->ticket_id }})"
                                    wire:confirm="Are you sure you want to close this ticket?\n\n{{ str($ticket->subject)->words(6) }} by @if($ticket->client_name != ''){{ $ticket->client_name }}@else{{ $ticket->public_name }}@endif?">
                                Close
                            </button>
                        </td>
                    </tr>
                @endforeach
                </tbody>
            </table>

            <div class="mt-3 mb-1 px-3">
                <div x-show="$wire.selectedRows.length > 0" x-cloak>
                    <form wire:submit="closeSelected">
                        <button type="submit" class="btn btn-sm btn-error dark:text-white float-start">Close <span
                                x-text="$wire.selectedRows.length"></span> tickets.
                        </button>
                    </form>
                </div>
                @if($tickets->total() > '10')
                    {{ $tickets->links('livewire.tickets.pagination') }}
                @endif
            </div>
        @else
            <div class="px-4 mt-4">
                <div
                    class="flex items-center p-4 mb-4 text-white rounded-lg alert bg-blue-900 dark:bg-gray-800"
                    role="alert">
                    Sorry there aren't any tickets.
                </div>
            </div>
        @endif
    </div>
</div>
