<x-app-layout>
    <x-slot name="header" class="flex bg-white dark:bg-gray-900 mt-10">
        <div class="grid grid-cols-6 gap-4">
            <div class="sm:col-span-4 col-span-6">
                <h2 class="font-semibold text-sm sm:text-base text-gray-800 dark:text-gray-200 leading-tight mt-6">
                    {{ __('Viewing Ticket') }}: {{ $ticket->subject }}
                </h2>
            </div>
            @if(Auth::check() && Auth::user()->is_agent == '1')
                <div class="sm:col-span-2 col-span-6">
                    <livewire:tickets.change-customer :customer_id="$ticket->user_id"
                                                      :ticket_id="$ticket->ticket_id"
                                                      :public_name="$ticket->public_name"/>
                </div>
            @endif
        </div>
    </x-slot>
    <div class="mt-3 max-w-7xl grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4 sm:gap-6 mx-auto">
        <div>
            <div class="card bg-white dark:bg-gray-900 text-neutral dark:text-gray-100">
                <div class="card-body">
                    <h2 class="card-title dark:text-white">Department</h2>
                    <h1 style="float-right">
                        <span class="capitalize">
                            {{ $ticket->department_name }}
                        </span>
                    </h1>
                </div>
            </div>
        </div>
        <div>
            <div class="card bg-white dark:bg-gray-900 text-neutral dark:text-gray-100">
                <div class="card-body">
                    <h2 class="card-title dark:text-white">Ticket Status</h2>
                    <h1 style="float: right;">
                        <span class="badge text-white text-xs px-2 py-2 border-transparent capitalize"
                              style="background: {{ $ticket->status->colour() ?? '#1f2937' }};">
                            {{ ucfirst($ticket->status->label() ?? 'Unknown Status') }}
                        </span>
                    </h1>
                </div>
            </div>
        </div>
        <div>
            <div class="card bg-white dark:bg-gray-900 text-neutral dark:text-gray-100">
                <div class="card-body">
                    <h2 class="card-title dark:text-white">Ticket Priority</h2>
                    <h1 style="float: right;">
                        <span class="badge text-white text-xs px-2 py-2 border-transparent capitalize"
                              style="background: {{ $ticket->priority->colour() ?? '#1f2937' }};">
                            {{ ucfirst($ticket->priority->label() ?? 'No Priority') }}
                        </span>
                    </h1>
                </div>
            </div>
        </div>
    </div>

    @if(Auth::check() and Auth::user()->is_agent == '1')
        <div class="mt-5">
            <div class="mx-auto overflow-x-auto">
                <div class="card bg-white dark:bg-gray-900 text-neutral dark:text-white">
                    <div class="card-body grid">
                        <div class="grid grid-cols-12 gap-11 mx-10">
                            <div class="md:col-span-3 col-span-12">
                                <livewire:tickets.change-department :current_department="$ticket->department_id"
                                                                    :ticket_id="$ticket->ticket_id"
                                                                    :department_name="$ticket->department_name"/>
                            </div>
                            <div class="md:col-span-3 col-span-12">
                                <livewire:tickets.change-status :current_status="$ticket->status"
                                                                :ticket_id="$ticket->ticket_id"/>
                            </div>
                            <div class="md:col-span-3 col-span-12">
                                <livewire:tickets.change-priority :current_priority="$ticket->priority"
                                                                  :ticket_id="$ticket->ticket_id"/>
                            </div>
                            <div class="md:col-span-3 col-span-12">
                                <livewire:tickets.assigned-to :current_assigned_agent="$ticket->assigned"
                                                              :ticket_id="$ticket->ticket_id"
                                                              :account_manager="$ticket->assigned"/>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    @endif

    <div class="mt-3">
        <div class="max-w-7xl mx-auto overflow-x-auto">
            <div class="card bg-white dark:bg-gray-900 text-neutral dark:text-gray-100">
                <div class="card-body">
                    <h1 style="float-right">
                        <div class="chat chat-start">
                            <div class="chat-image avatar">
                                <div class="w-10 rounded-full">
                                    @if($ticket->profile_photo_path != '')
                                        <img class="h-8 w-8 rounded-full object-cover"
                                             src="{{ env('APP_URL')  }}/storage/{{ $ticket->profile_photo_path }}"
                                             alt="{{ $ticket->name }}"/>
                                    @else
                                        <img class="h-8 w-8 rounded-full object-cover"
                                             src="@php echo "https://gravatar.com/avatar/". hash('sha256', strtolower(trim($ticket->email))).".png"; @endphp"
                                             alt="{{ $ticket->name }}"/>
                                    @endif
                                </div>
                            </div>
                            <div class="chat-header">
                                @if($ticket->client_name != '')
                                    {{ $ticket->client_name }} @if($ticket->company_name)
                                        :: {{ $ticket->company_name  }}
                                    @endif
                                @else
                                    {{ $ticket->public_name }} :: {{ $ticket->public_email  }}
                                @endif
                            </div>
                            <div class="chat-bubble whitespace-pre-line">
                                {{ $ticket->content }}
                                <livewire:tickets.ratings :rating="$ticket->rating" :ticket_id="$ticket->ticket_id"
                                                          :client_id="$ticket->user_id"/>
                            </div>
                            <div class="chat-footer opacity-70">
                    <span
                        class="flex text-xs font-normal text-gray-500 dark:text-gray-400 space-x-1">
                            Replied: <time class="text-xs dark:text-white">
                                        {{ Carbon\Carbon::parse($ticket->created_at)->format('jS F Y H:i') }}
                                    </time>
                        </span>
                            </div>
                            <div class="chat-footer opacity-70 mt-4">
                    <span
                        class="flex text-xs font-normal text-gray-500 dark:text-gray-400 space-x-1">
                            IP Address: {{ $ticket->ip_address }}
                        </span>
                            </div>
                        </div>
                        <div>
                            <livewire:tickets.replies :ticket_id="$ticket->ticket_id"/>
                        </div>
                    </h1>
                </div>
            </div>
        </div>
    </div>

    <div class="mt-3">
        <div class="max-w-7xl mx-auto overflow-x-auto">
            <div class="card bg-white dark:bg-gray-900 text-neutral dark:text-gray-100">
                <div class="card-body">
                    <livewire:tickets.comment-box :ticket_id="$ticket->ticket_id"/>
                </div>
            </div>
        </div>
    </div>
</x-app-layout>
